==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/firewall/translations/firewall_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>Firewall</source>
        <translation>Firewall</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Notify</source>
        <translation>Powiadamianie</translation>
    </message>
    <message>
        <source>Notification syntax</source>
        <translation>Składnia powiadomienia</translation>
    </message>
    <message>
        <source>%u - uin, %m - message</source>
        <translation>%u - uin, %m - wiadomość</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Logowanie</translation>
    </message>
    <message>
        <source>Write to history</source>
        <translation>Zapisz w historii</translation>
    </message>
    <message>
        <source>Write log to file</source>
        <translation>Zapisuj wypowiedzi do pliku</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Wyszukiwanie</translation>
    </message>
    <message>
        <source>Search for unknown person in directory and show window with his personal data.</source>
        <translation>Szukaj nieznanej osoby w katalogu i wyświetlaj okno z informacją o niej.</translation>
    </message>
    <message>
        <source>Unknown chats protection</source>
        <translation>Ochrona przed nieznanymi osobami</translation>
    </message>
    <message>
        <source>Ignore conferences with all persons unknown</source>
        <translation>Ignoruj konferencje, jeśli wszystkie osoby są nieznane</translation>
    </message>
    <message>
        <source>Protect against chats with unknown persons</source>
        <translation>Chroń przed rozmowami z nieznaną osobą</translation>
    </message>
    <message>
        <source>When invisible silently drop chats with unknown persons</source>
        <translation>Ciche odrzucanie rozmów z nieznajomymi gdy jesteśmy ukryci</translation>
    </message>
    <message>
        <source>Automatic question</source>
        <translation>Automatyczne pytanie</translation>
    </message>
    <message>
        <source>After right answer</source>
        <translation>Po poprawnej odpowiedzi</translation>
    </message>
    <message>
        <source>Send confirmation</source>
        <translation>Wyślij potwierdzenie</translation>
    </message>
    <message>
        <source>Confirmation</source>
        <translation>Potwierdzenie</translation>
    </message>
    <message>
        <source>DoS attack</source>
        <translation>Atak DoS</translation>
    </message>
    <message>
        <source>Protect against flooding DoS attack</source>
        <translation>Chroń przed atakiem DoS</translation>
    </message>
    <message>
        <source>Attack caused by many messages, sent in short time.</source>
        <translation>Atak spowodowany dużą ilością wiadomości, wysłanych w krótkim czasie.</translation>
    </message>
    <message>
        <source>Min delay between two messages</source>
        <translation>Minimalny czas pomiędzy wiadomościami</translation>
    </message>
    <message>
        <source>Emoticons DoS attack</source>
        <translation>Atak DoS emotikonami</translation>
    </message>
    <message>
        <source>Protect against emoticons DoS attack</source>
        <translation>Chroń przed atakiem emotikonami</translation>
    </message>
    <message>
        <source>Attack caused by many emoticons, sent in short time.</source>
        <translation>Atak spowodowany dużą ilością emotikon, wysłanych w krótkim czasie.</translation>
    </message>
    <message>
        <source>Max number of emoticons in one message</source>
        <translation>Maksymalna dopuszczalna liczba emotikon</translation>
    </message>
    <message>
        <source>Allow if known contact</source>
        <translation>Pozwalaj, jeśli z listy kontaktów</translation>
    </message>
    <message>
        <source>People from your list can send you unlimited number of emoticons</source>
        <translation>Osoby z listy kontaktów mogą przesyłać ci nieograniczoną liczbę emotikon</translation>
    </message>
    <message>
        <source>Safe sending</source>
        <translation>Bezpieczne wysyłanie</translation>
    </message>
    <message>
        <source>Enable safe sending</source>
        <translation>Włącz bezpieczne wysyłanie</translation>
    </message>
    <message>
        <source>You must confirm each message sent to these people</source>
        <translation>Musisz potwierdzić chęć wysłania wiadomości do tych osób</translation>
    </message>
    <message numerus="yes">
        <source>%n millisecond(s)</source>
        <translation>
            <numerusform>%n milisekunda</numerusform>
            <numerusform>%n milisekundy</numerusform>
            <numerusform>%n milisekund</numerusform>
        </translation>
    </message>
    <message>
        <source>Message was firewalled</source>
        <translation>Wiadomość została zablokowana</translation>
    </message>
    <message>
        <source>Module will ask the question typed below, if someone wants talk to you and you do not have him on your list.</source>
        <translation>Wtyczka wyśle poniższe zapytanie kiedy ktoś nieznajdujący się na liście będzie chciał rozpocząć rozmowę.</translation>
    </message>
</context>
<context>
    <name>Firewall</name>
    <message>
        <source>I want something</source>
        <translation>coś chcę</translation>
    </message>
    <message>
        <source>flooding DoS attack with emoticons!</source>
        <translation>atak DoS z emotikonami!</translation>
    </message>
    <message>
        <source>flooding DoS attack!</source>
        <translation>atak DoS!</translation>
    </message>
    <message>
        <source>Chat with anonim silently dropped.
</source>
        <translation>Rozmowa z anonimem po cichu odrzucona.</translation>
    </message>
    <message>
        <source>OK, now say hello, and introduce yourself ;-)</source>
        <translation>OK, teraz ładnie się przedstaw ;-)</translation>
    </message>
    <message>
        <source>User wrote right answer!
</source>
        <translation>Użytkownik udzielił prawidłowej odpowiedzi
</translation>
    </message>
    <message>
        <source>This message has been generated AUTOMATICALLY!

I&apos;m a busy person and I don&apos;t have time for stupid chats. Find another person to chat with. If you REALLY want something from me, simple type &quot;I want something&quot; (capital doesn&apos;t matter)</source>
        <translation>Ta wiadomość została wygenerowana AUTOMATYCZNIE!

Nie mam cię na mojej liście kontaktów i jeśli chcesz mi coś napisać, to wpisz po prostu &quot;coś chcę&quot; - wszystkie inne wiadomości są kasowane i nie widzę ich treści.
Jeśli chcesz natomiast &quot;poklikać&quot;, to znajdź sobie do tego inną osobę, a najlepiej zajmij się czymś pożyteczniejszym!</translation>
    </message>
    <message>
        <source>Are you sure you want to send this message?</source>
        <translation>Czy na pewno chcesz wysłać tę wiadomość?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Tak</translation>
    </message>
    <message>
        <source>Yes and allow until chat closed</source>
        <translation>Tak i pozwalaj dopóki prowadzisz rozmowę</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nie</translation>
    </message>
    <message>
        <source>%u writes</source>
        <translation>Anonim [%u] napisał</translation>
    </message>
    <message>
        <source>This message has been generated AUTOMATICALLY!

I&apos;m a busy person and I don&apos;t have time for stupid chats with the persons hiding itself. If you want to talk with me change the status to Online or Busy first.</source>
        <translation>Ta wiadomość została wygenerowana AUTOMATYCZNIE!

Jestem zajętą osobą i nie mam czasu na rozmowy z ukrywającymi się osobami. Jeśli chcesz ze mną rozmawiać, zmień wcześniej swój status na Dostępny.</translation>
    </message>
    <message>
        <source>Chat with invisible anonim ignored.
</source>
        <translation>Rozmowa z niewidocznym anonimem zignorowana.
</translation>
    </message>
    <message>
        <source>      DATA AND TIME      ::   ID      :: MESSAGE
</source>
        <translation>      DATA I CZAS      ::   ID      :: WIADOMOŚĆ
</translation>
    </message>
</context>
<context>
    <name>FirewallConfigurationUiHandler</name>
    <message>
        <source>Move to &apos;Secured&apos;</source>
        <translation>Przenieś do &apos;Zabezpieczeni&apos;</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Wszyscy</translation>
    </message>
    <message>
        <source>Move to &apos;All&apos;</source>
        <translation>Przenieś do &apos;Wszyscy&apos;</translation>
    </message>
    <message>
        <source>Secured</source>
        <translation>Zabezpieczeni</translation>
    </message>
    <message>
        <source>This message will be send to unknown person.</source>
        <translation>Ta wiadomość zostanie wysłana do nieznanej osoby.</translation>
    </message>
    <message>
        <source>Right answer for question above - you can use regexp.</source>
        <translation>Prawidłowa odpowiedź na powyższe pytanie - można używać regexp.</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Odpowiedź:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Tekst pytania:</translation>
    </message>
</context>
<context>
    <name>FirewallNotification</name>
    <message>
        <source>Message was blocked</source>
        <translation>Wiadomość została zablokowana</translation>
    </message>
    <message>
        <source>%u writes</source>
        <translation>Anonim [%u] napisał</translation>
    </message>
</context>
</TS>

==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/firewall/translations/firewall_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Firewall</source>
        <translation>Firewall</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Notify</source>
        <translation>Powiadamianie</translation>
    </message>
    <message>
        <source>Notification syntax</source>
        <translation>Składnia powiadomienia</translation>
    </message>
    <message>
        <source>%u - uin, %m - message</source>
        <translation>%u - uin, %m - wiadomość</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Logowanie</translation>
    </message>
    <message>
        <source>Write to history</source>
        <translation>Zapisz w historii</translation>
    </message>
    <message>
        <source>Write log to file</source>
        <translation>Zapisuj wypowiedzi do pliku</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Wyszukiwanie</translation>
    </message>
    <message>
        <source>Search for unknown person in directory and show window with his personal data.</source>
        <translation>Szukaj nieznanej osoby w katalogu i wyświetlaj okno z informacją o niej.</translation>
    </message>
    <message>
        <source>Unknown chats protection</source>
        <translation>Ochrona przed nieznanymi osobami</translation>
    </message>
    <message>
        <source>Ignore conferences with all persons unknown</source>
        <translation>Ignoruj konferencje, jeśli wszystkie osoby są nieznane</translation>
    </message>
    <message>
        <source>Protect against chats with unknown persons</source>
        <translation>Chroń przed rozmowami z nieznaną osobą</translation>
    </message>
    <message>
        <source>When invisible silently drop chats with unknown persons</source>
        <translation>Ciche odrzucanie rozmów z nieznajomymi gdy jesteśmy ukryci</translation>
    </message>
    <message>
        <source>Automatic question</source>
        <translation>Automatyczne pytanie</translation>
    </message>
    <message>
        <source>After right answer</source>
        <translation>Po poprawnej odpowiedzi</translation>
    </message>
    <message>
        <source>Send confirmation</source>
        <translation>Wyślij potwierdzenie</translation>
    </message>
    <message>
        <source>Confirmation</source>
        <translation>Potwierdzenie</translation>
    </message>
    <message>
        <source>DoS attack</source>
        <translation>Atak DoS</translation>
    </message>
    <message>
        <source>Protect against flooding DoS attack</source>
        <translation>Chroń przed atakiem DoS</translation>
    </message>
    <message>
        <source>Attack caused by many messages, sent in short time.</source>
        <translation>Atak spowodowany dużą ilością wiadomości, wysłanych w krótkim czasie.</translation>
    </message>
    <message>
        <source>Min delay between two messages</source>
        <translation>Minimalny czas pomiędzy wiadomościami</translation>
    </message>
    <message>
        <source>Emoticons DoS attack</source>
        <translation>Atak DoS emotikonami</translation>
    </message>
    <message>
        <source>Protect against emoticons DoS attack</source>
        <translation>Chroń przed atakiem emotikonami</translation>
    </message>
    <message>
        <source>Attack caused by many emoticons, sent in short time.</source>
        <translation>Atak spowodowany dużą ilością emotikon, wysłanych w krótkim czasie.</translation>
    </message>
    <message>
        <source>Max number of emoticons in one message</source>
        <translation>Maksymalna dopuszczalna liczba emotikon</translation>
    </message>
    <message>
        <source>Allow if known contact</source>
        <translation>Pozwalaj, jeśli z listy kontaktów</translation>
    </message>
    <message>
        <source>People from your list can send you unlimited number of emoticons</source>
        <translation>Osoby z listy kontaktów mogą przesyłać ci nieograniczoną liczbę emotikon</translation>
    </message>
    <message>
        <source>Safe sending</source>
        <translation>Bezpieczne wysyłanie</translation>
    </message>
    <message>
        <source>Enable safe sending</source>
        <translation>Włącz bezpieczne wysyłanie</translation>
    </message>
    <message>
        <source>You must confirm each message sent to these people</source>
        <translation>Musisz potwierdzić chęć wysłania wiadomości do tych osób</translation>
    </message>
    <message numerus="yes">
        <source>%n millisecond(s)</source>
        <translation><numerusform>%n milisekunda</numerusform><numerusform>%n milisekundy</numerusform><numerusform>%n milisekund</numerusform></translation>
    </message>
    <message>
        <source>Message was firewalled</source>
        <translation>Wiadomość została zablokowana</translation>
    </message>
    <message>
        <source>Module will ask the question typed below, if someone wants talk to you and you do not have him on your list.</source>
        <translation>Wtyczka wyśle poniższe zapytanie kiedy ktoś nieznajdujący się na liście będzie chciał rozpocząć rozmowę.</translation>
    </message>
</context>
<context>
    <name>Firewall</name>
    <message>
        <source>I want something</source>
        <translation>coś chcę</translation>
    </message>
    <message>
        <source>flooding DoS attack with emoticons!</source>
        <translation>atak DoS z emotikonami!</translation>
    </message>
    <message>
        <source>flooding DoS attack!</source>
        <translation>atak DoS!</translation>
    </message>
    <message>
        <source>Chat with anonim silently dropped.
</source>
        <translation>Rozmowa z anonimem po cichu odrzucona.</translation>
    </message>
    <message>
        <source>OK, now say hello, and introduce yourself ;-)</source>
        <translation>OK, teraz ładnie się przedstaw ;-)</translation>
    </message>
    <message>
        <source>User wrote right answer!
</source>
        <translation>Użytkownik udzielił prawidłowej odpowiedzi
</translation>
    </message>
    <message>
        <source>This message has been generated AUTOMATICALLY!

I&apos;m a busy person and I don&apos;t have time for stupid chats. Find another person to chat with. If you REALLY want something from me, simple type &quot;I want something&quot; (capital doesn&apos;t matter)</source>
        <translation>Ta wiadomość została wygenerowana AUTOMATYCZNIE!

Nie mam cię na mojej liście kontaktów i jeśli chcesz mi coś napisać, to wpisz po prostu &quot;coś chcę&quot; - wszystkie inne wiadomości są kasowane i nie widzę ich treści.
Jeśli chcesz natomiast &quot;poklikać&quot;, to znajdź sobie do tego inną osobę, a najlepiej zajmij się czymś pożyteczniejszym!</translation>
    </message>
    <message>
        <source>Are you sure you want to send this message?</source>
        <translation>Czy na pewno chcesz wysłać tę wiadomość?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Tak</translation>
    </message>
    <message>
        <source>Yes and allow until chat closed</source>
        <translation>Tak i pozwalaj dopóki prowadzisz rozmowę</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nie</translation>
    </message>
    <message>
        <source>%u writes</source>
        <translation>Anonim [%u] napisał</translation>
    </message>
    <message>
        <source>This message has been generated AUTOMATICALLY!

I&apos;m a busy person and I don&apos;t have time for stupid chats with the persons hiding itself. If you want to talk with me change the status to Online or Busy first.</source>
        <translation>Ta wiadomość została wygenerowana AUTOMATYCZNIE!

Jestem zajętą osobą i nie mam czasu na rozmowy z ukrywającymi się osobami. Jeśli chcesz ze mną rozmawiać, zmień wcześniej swój status na Dostępny.</translation>
    </message>
    <message>
        <source>Chat with invisible anonim ignored.
</source>
        <translation>Rozmowa z niewidocznym anonimem zignorowana.
</translation>
    </message>
    <message>
        <source>      DATA AND TIME      ::   ID      :: MESSAGE
</source>
        <translation>      DATA I CZAS      ::   ID      :: WIADOMOŚĆ
</translation>
    </message>
</context>
<context>
    <name>FirewallConfigurationUiHandler</name>
    <message>
        <source>Move to &apos;Secured&apos;</source>
        <translation>Przenieś do &apos;Zabezpieczeni&apos;</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Wszyscy</translation>
    </message>
    <message>
        <source>Move to &apos;All&apos;</source>
        <translation>Przenieś do &apos;Wszyscy&apos;</translation>
    </message>
    <message>
        <source>Secured</source>
        <translation>Zabezpieczeni</translation>
    </message>
    <message>
        <source>This message will be send to unknown person.</source>
        <translation>Ta wiadomość zostanie wysłana do nieznanej osoby.</translation>
    </message>
    <message>
        <source>Right answer for question above - you can use regexp.</source>
        <translation>Prawidłowa odpowiedź na powyższe pytanie - można używać regexp.</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Odpowiedź:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Tekst pytania:</translation>
    </message>
</context>
<context>
    <name>FirewallNotification</name>
    <message>
        <source>Message was blocked</source>
        <translation>Wiadomość została zablokowana</translation>
    </message>
    <message>
        <source>%u writes</source>
        <translation>Anonim [%u] napisał</translation>
    </message>
</context>
</TS>
